summaryrefslogtreecommitdiff
path: root/gio/gpollableoutputstream.c
diff options
context:
space:
mode:
Diffstat (limited to 'gio/gpollableoutputstream.c')
-rw-r--r--gio/gpollableoutputstream.c41
1 files changed, 31 insertions, 10 deletions
diff --git a/gio/gpollableoutputstream.c b/gio/gpollableoutputstream.c
index f8656b32e..57568e316 100644
--- a/gio/gpollableoutputstream.c
+++ b/gio/gpollableoutputstream.c
@@ -46,7 +46,7 @@ G_DEFINE_INTERFACE (GPollableOutputStream, g_pollable_output_stream, G_TYPE_OUTP
static gboolean g_pollable_output_stream_default_can_poll (GPollableOutputStream *stream);
static gssize g_pollable_output_stream_default_write_nonblocking (GPollableOutputStream *stream,
const void *buffer,
- gsize size,
+ gsize count,
GError **error);
static void
@@ -145,7 +145,7 @@ g_pollable_output_stream_create_source (GPollableOutputStream *stream,
static gssize
g_pollable_output_stream_default_write_nonblocking (GPollableOutputStream *stream,
const void *buffer,
- gsize size,
+ gsize count,
GError **error)
{
if (!g_pollable_output_stream_is_writable (stream))
@@ -155,20 +155,20 @@ g_pollable_output_stream_default_write_nonblocking (GPollableOutputStream *stre
return -1;
}
- return g_output_stream_write (G_OUTPUT_STREAM (stream), buffer, size,
- NULL, error);
+ return G_OUTPUT_STREAM_GET_CLASS (stream)->
+ write_fn (G_OUTPUT_STREAM (stream), buffer, count, NULL, error);
}
/**
* g_pollable_output_stream_write_nonblocking:
* @stream: a #GPollableOutputStream
* @buffer: (array length=size) (element-type guint8): a buffer to write
* data from
* @size: the number of bytes you want to write
* @cancellable: (allow-none): a #GCancellable, or %NULL
* @error: #GError for error reporting, or %NULL to ignore.
*
* Attempts to write up to @size bytes from @buffer to @stream, as
* with g_output_stream_write(). If @stream is not currently writable,
* this will immediately return %G_IO_ERROR_WOULD_BLOCK, and you can
* use g_pollable_output_stream_create_source() to create a #GSource
@@ -187,15 +187,36 @@ g_pollable_output_stream_default_write_nonblocking (GPollableOutputStream *stre
gssize
g_pollable_output_stream_write_nonblocking (GPollableOutputStream *stream,
const void *buffer,
- gsize size,
+ gsize count,
GCancellable *cancellable,
GError **error)
{
+ gssize res;
+
g_return_val_if_fail (G_IS_POLLABLE_OUTPUT_STREAM (stream), -1);
+ g_return_val_if_fail (buffer != NULL, 0);
if (g_cancellable_set_error_if_cancelled (cancellable, error))
return -1;
- return G_POLLABLE_OUTPUT_STREAM_GET_INTERFACE (stream)->
- write_nonblocking (stream, buffer, size, error);
+ if (count == 0)
+ return 0;
+
+ if (((gssize) count) < 0)
+ {
+ g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_ARGUMENT,
+ _("Too large count value passed to %s"), G_STRFUNC);
+ return -1;
+ }
+
+ if (cancellable)
+ g_cancellable_push_current (cancellable);
+
+ res = G_POLLABLE_OUTPUT_STREAM_GET_INTERFACE (stream)->
+ write_nonblocking (stream, buffer, count, error);
+
+ if (cancellable)
+ g_cancellable_pop_current (cancellable);
+
+ return res;
}
@@ -155,20 +155,20 @@ g_pollable_output_stream_default_write_nonblocking (GPollableOutputStream *stre
* g_pollable_output_stream_write_nonblocking:
* @stream: a #GPollableOutputStream
- * @buffer: (array length=size) (element-type guint8): a buffer to write
+ * @buffer: (array length=count) (element-type guint8): a buffer to write
* data from
@@ -155,20 +155,20 @@ g_pollable_output_stream_default_write_nonblocking (GPollableOutputStream *stre
* data from
- * @size: the number of bytes you want to write
+ * @count: the number of bytes you want to write
* @cancellable: (allow-none): a #GCancellable, or %NULL
* @error: #GError for error reporting, or %NULL to ignore.
@@ -155,20 +155,20 @@ g_pollable_output_stream_default_write_nonblocking (GPollableOutputStream *stre
* @error: #GError for error reporting, or %NULL to ignore.
*
- * Attempts to write up to @size bytes from @buffer to @stream, as
+ * Attempts to write up to @count bytes from @buffer to @stream, as
* with g_output_stream_write(). If @stream is not currently writable,
* this will immediately return %G_IO_ERROR_WOULD_BLOCK, and you can